@@ -37,15 +37,13 @@ snp_scaleBinom <- function(nploidy = 2) {
 
   function(X,
            ind.row = rows_along(X),
-           ind.col = cols_along(X)) {
+           ind.col = cols_along(X),
+           ncores = 1) {
 
-    means <- big_colstats(X, ind.row = ind.row, ind.col = ind.col)$sum /
-      length(ind.row)
+    af <- snp_colstats(X, ind.row, ind.col, ncores)$sumX /
+      (length(ind.row) * nploidy)
 
-    p <- means / nploidy
-    sds <- sqrt(nploidy * p * (1 - p))
-
-    data.frame(center = means, scale = sds)
+    data.frame(center = nploidy * af, scale = sqrt(nploidy * af * (1 - af)))
   }
 }
 
@@ -70,12 +68,10 @@ snp_MAF <- function(G,
                     nploidy = 2,
                     ncores = 1) {
 
-  ac <- big_parallelize(G, function(X, ind, ind.row) {
-    big_colstats(X, ind.row = ind.row, ind.col = ind)$sum
-  }, ind = ind.col, ind.row = ind.row, p.combine = 'c', ncores = ncores)
+  af <- snp_colstats(G, ind.row, ind.col, ncores)$sumX /
+    (length(ind.row) * nploidy)
 
-  p <- ac / (nploidy * length(ind.row))
-  pmin(p, 1 - p)
+  pmin(af, 1 - af)
 }
 
 ################################################################################
@@ -105,16 +101,21 @@ snp_MAF <- function(G,
 #'
 bed_scaleBinom <- function(obj.bed,
                            ind.row = rows_along(obj.bed),
-                           ind.col = cols_along(obj.bed)) {
+                           ind.col = cols_along(obj.bed),
+                           ncores = 1) {
 
-  stats <- bed_stats(obj.bed, ind.row, ind.col)
-  af <- stats$sum / (2 * stats$nb_nona_col)
+  stats <- bed_colstats(obj.bed, ind.row, ind.col, ncores)
+  af <- stats$sumX / (2 * stats$nb_nona_col)
 
   data.frame(center = 2 * af, scale = sqrt(2 * af * (1 - af)))
 }
 
 ################################################################################
 
+part_bed_row_counts <- function(X, ind, ind.row) {
+  bed_row_counts_cpp(obj_bed = X, ind_row = ind.row, ind_col = ind)
+}
+
 #' Counts
 #'
 #' Counts the number of 0s, 1s, 2s and NAs by variants in the bed file.
@@ -142,13 +143,11 @@ bed_counts <- function(obj.bed,
                        ncores = 1) {
 
   if (byrow) {
-    res <- big_parallelize(obj.bed, p.FUN = function(X, ind, ind.row) {
-      bed_row_counts_cpp(obj.bed, ind.row, ind)
-    }, p.combine = plus, ncores = ncores, ind = ind.col, ind.row = ind.row)
+    res <- big_parallelize(obj.bed$light, p.FUN = part_bed_row_counts,
+                           p.combine = plus, ncores = ncores,
+                           ind = ind.col, ind.row = ind.row)
   } else {
-    res <- big_parallelize(obj.bed, p.FUN = function(X, ind, ind.row) {
-      bed_counts_cpp(obj.bed, ind.row, ind)
-    }, p.combine = "cbind", ncores = ncores, ind = ind.col, ind.row = ind.row)
+    res <- bed_col_counts_cpp(obj.bed, ind.row, ind.col, ncores)
   }
 
   rownames(res) <- c(0:2, NA)
@@ -198,5 +197,3 @@ bed_MAF <- function(obj.bed,
 }
 
 ################################################################################
-
-
