@@ -2,8 +2,7 @@
 
 flip_strand <- function(allele) {
 
-  if (!requireNamespace("dplyr", quietly = TRUE))
-    stop2("Please install package 'dplyr'.")
+  assert_package("dplyr")
 
   dplyr::case_when(
     allele == "A" ~ "T",
@@ -89,7 +88,7 @@ snp_match <- function(sumstats, info_snp,
            format(sum(matched$`_FLIP_`), big.mark = ","),
            format(sum(matched$`_REV_`),  big.mark = ","))
 
-  if (nrow(matched) < (match.min.prop * min(ncol(sumstats), ncol(info_snp))))
+  if (nrow(matched) < (match.min.prop * min(nrow(sumstats), nrow(info_snp))))
     stop2("Not enough variants have been matched.")
 
   as.data.frame(matched[, c("_FLIP_", "_REV_") := NULL][order(chr, pos)])
@@ -226,3 +225,41 @@ same_ref <- function(ref1, alt1, ref2, alt2) {
 }
 
 ################################################################################
+
+#' Interpolate to genetic positions
+#'
+#' Use genetic maps available at
+#' \url{https://github.com/joepickrell/1000-genomes-genetic-maps/}
+#' to interpolate physical positions (in bp) to genetic positions (in cM).
+#'
+#' @inheritParams bigsnpr-package
+#' @param dir Directory where to download and decompress files.
+#'   Default is `tempdir()`. Directly use files there if already present.
+#'
+#' @return The new vector of genetic positions.
+#' @export
+#'
+snp_asGeneticPos <- function(infos.chr, infos.pos, dir = tempdir(), ncores = 1) {
+
+  assert_package("R.utils")
+  assert_lengths(infos.chr, infos.pos)
+
+  snp_split(infos.chr, function(ind.chr, pos, dir) {
+    chr <- attr(ind.chr, "chr")
+    basename <- paste0("chr", chr, ".OMNI.interpolated_genetic_map")
+    mapfile <- file.path(dir, basename)
+    if (!file.exists(mapfile)) {
+      url <- paste0("https://github.com/joepickrell/1000-genomes-genetic-maps/",
+                    "raw/master/interpolated_OMNI/", basename, ".gz")
+      gzfile <- paste0(mapfile, ".gz")
+      utils::download.file(url, destfile = gzfile, quiet = TRUE)
+      R.utils::gunzip(gzfile)
+    }
+    map.chr <- bigreadr::fread2(mapfile, showProgress = FALSE)
+    ind <- bigutilsr::knn_parallel(as.matrix(map.chr$V2), as.matrix(pos[ind.chr]),
+                                   k = 1, ncores = 1)$nn.idx
+    map.chr$V3[ind]
+  }, combine = "c", pos = infos.pos, dir = dir, ncores = ncores)
+}
+
+################################################################################
